/*********************************************************
*Copyright (C), 2017, Shanghai Eastsoft Microelectronics Co., Ltd.
*文件名:  timer.h
*作  者:  AE Team
*版  本:  V1.01
*日  期:  2021/05/19
*描  述:  Timer模块程序头文件
*备  注:  本软件仅供学习和演示使用，对用户直接引用代码所带来的风险或后果不承担任何法律责任。
**********************************************************/
#include "timer.h"


/*********************************************************
函数名: void T16Nx_Pins_Init(void)
描  述: T16Nx PWM输出pin脚初始化
输入值: 无
输出值: 无
返回值: 无
**********************************************************/
void T16Nx_Pins_Init(void)
{
    GPIO_InitSettingType x;

    x.Signal = GPIO_Pin_Signal_Digital;
    x.Dir = GPIO_Direction_Output;
    x.Func = GPIO_Reuse_Func2;
    x.ODE = GPIO_ODE_Output_Disable;
    x.DS = GPIO_DS_Output_Normal;
    x.PUE = GPIO_PUE_Input_Enable;
    x.PDE = GPIO_PDE_Input_Disable;

    /* 配置PA4、PA5分别为T16N0输出通道1和输出通道0 */
    GPIO_Init(GPIO_Pin_A4, &x);
    GPIO_Init(GPIO_Pin_A5, &x);
}

/*********************************************************
函数名: void T16NxInit(void)
描  述: T16Nx定时器初始化
输入值: 无
输出值: 无
返回值: 无
**********************************************************/
void T16NxInit(void)
{
    T16Nx_BaseInitStruType x;
    T16Nx_PWMInitStruType y;

    /* 初始化T16Nx定时器*/
    x.T16Nx_ClkS = T16Nx_ClkS_PCLK;
    x.T16Nx_SYNC = Disable;
    x.T16Nx_EDGE = T16Nx_EDGE_Rise;
    x.T16Nx_Mode = T16Nx_Mode_PWM;
    x.T16Nx_PREMAT = 0x01;          /* 预分频比1:1 */
    T16Nx_BaseInit(T16N0, &x);

    /* 配置T16N0输出 */
    y.T16Nx_MOE0 = Enable;
    y.T16Nx_MOE1 = Enable;
    y.T16Nx_POL0 = POSITIVE;
    y.T16Nx_POL1 = POSITIVE;
    y.T16Nx_PWMMODE = T16Nx_PWMMode_COMPLE;
    y.PWMDZE = Enable;
	y.REGBUFEN = Enable;
    T16Nx_PMWOutInit(T16N0, &y);

    T16Nx_MAT0ITConfig(T16N0, T16Nx_Go_No);
    T16Nx_MAT1ITConfig(T16N0, T16Nx_Clr_Int);
    T16Nx_MAT0Out0Config(T16N0, T16Nx_Out_High);
    T16Nx_MAT1Out0Config(T16N0, T16Nx_Out_Low);
    T16Nx_SetCNT0(T16N0, 0);
    T16Nx_SetMAT0(T16N0, 1600);
    T16Nx_SetMAT1(T16N0, 3200);
    T16Nx_SetTOP0(T16N0, 3200);
    T16Nx_PWMPDZ_Config(T16N0, 70);

    T16Nx_ITConfig(T16N0, T16Nx_IT_MAT1, Enable);
    NVIC_Init(NVIC_T16N0_IRQn, NVIC_Priority_1, Enable);

    T16Nx_Pins_Init();

    T16Nx_Enable(T16N0);

    return;
}

