/*********************************************************
*Copyright (C), 2017, Shanghai Eastsoft Microelectronics Co., Ltd.
*文件名:  timer.h
*作  者:  AE Team
*版  本:  V1.01
*日  期:  2021/05/19
*描  述:  Timer模块程序头文件
*备  注:  本软件仅供学习和演示使用，对用户直接引用代码所带来的风险或后果不承担任何法律责任。
**********************************************************/
#include "timer.h"

uint32_t Period = 8000;
uint32_t dutytab[5] = {8000 * 2, 8000 * 3, 8000 * 4, 8000 * 5, 8000 * 6};


/*********************************************************
函数名: void T16Nx_Pins_Init(void)
描  述: T16Nx PWM输出pin脚初始化
输入值: 无
输出值: 无
返回值: 无
**********************************************************/
void T16Nx_Pins_Init(void)
{
    GPIO_InitSettingType x;

    x.Signal = GPIO_Pin_Signal_Digital;
    x.Dir = GPIO_Direction_Output;
    x.Func = GPIO_Reuse_Func2;
    x.ODE = GPIO_ODE_Output_Disable;
    x.DS = GPIO_DS_Output_Normal;
    x.PUE = GPIO_PUE_Input_Enable;
    x.PDE = GPIO_PDE_Input_Disable;

    /* 配置PA4、PA5分别为T16N0输出通道1和输出通道0 */
    GPIO_Init(GPIO_Pin_A4, &x);
    GPIO_Init(GPIO_Pin_A5, &x);
    /* 配置PA8分别为T16N1输出通道0 */
    GPIO_Init(GPIO_Pin_A8, &x);
}

/*********************************************************
函数名: void T16NxInit(void)
描  述: T16Nx定时器初始化
输入值: 无
输出值: 无
返回值: 无
**********************************************************/
void T16NxInit(void)
{
    T16Nx_BaseInitStruType x;
    T16Nx_PWMInitStruType y;

    /* 初始化T16Nx定时器*/
    x.T16Nx_ClkS = T16Nx_ClkS_PCLK;
    x.T16Nx_SYNC = Disable;
    x.T16Nx_EDGE = T16Nx_EDGE_Rise;
    x.T16Nx_Mode = T16Nx_Mode_PWM;
    x.T16Nx_PREMAT = 0x01;          /* 预分频比1:1 */
    T16Nx_BaseInit(T16N0, &x);
    T16Nx_BaseInit(T16N1, &x);

    /* 配置T16N0通道0及通道1输出，配置T16N1输出通道1 */
    y.T16Nx_MOE0 = Enable;
    y.T16Nx_MOE1 = Enable;
    y.T16Nx_POL0 = POSITIVE;
    y.T16Nx_POL1 = POSITIVE;
    y.T16Nx_PWMMODE = T16Nx_PWMMode_INDEP;
    y.PWMDZE = Disable;
	y.REGBUFEN = Enable;
    T16Nx_PMWOutInit(T16N0, &y);
    y.T16Nx_MOE1 = Disable;
    T16Nx_PMWOutInit(T16N1, &y);

    /* 配置T16N0 通道0输出 */
    T16Nx_MAT0ITConfig(T16N0, T16Nx_Go_No);
    T16Nx_MAT1ITConfig(T16N0, T16Nx_Go_Int);
    T16Nx_MAT0Out0Config(T16N0, T16Nx_Out_High);
    T16Nx_MAT1Out0Config(T16N0, T16Nx_Out_Low);
    T16Nx_SetCNT0(T16N0, 0);
    T16Nx_SetMAT0(T16N0, Period);
    T16Nx_SetMAT1(T16N0, dutytab[0]);
    T16Nx_SetTOP0(T16N0, dutytab[0]);	

    /* 配置T16N0 通道1输出 */
    T16Nx_MAT2ITConfig(T16N0, T16Nx_Go_No);
    T16Nx_MAT3ITConfig(T16N0, T16Nx_Clr_Int);
    T16Nx_MAT2Out1Config(T16N0, T16Nx_Out_High);
    T16Nx_MAT3Out1Config(T16N0, T16Nx_Out_Low);
    T16Nx_SetCNT1(T16N0, 0);
    T16Nx_SetMAT2(T16N0, dutytab[1]);
    T16Nx_SetMAT3(T16N0, dutytab[2]);
    T16Nx_SetTOP1(T16N0, dutytab[2]);	

    /* 配置T16N1通道0输出 */
    T16Nx_MAT0ITConfig(T16N1, T16Nx_Go_No);
    T16Nx_MAT1ITConfig(T16N1, T16Nx_Clr_Int);
    T16Nx_MAT0Out0Config(T16N1, T16Nx_Out_High);
    T16Nx_MAT1Out0Config(T16N1, T16Nx_Out_Low);
    T16Nx_SetCNT0(T16N1, 0);
    T16Nx_SetMAT0(T16N1, dutytab[1]);
    T16Nx_SetMAT1(T16N1, dutytab[2]);
    T16Nx_SetTOP0(T16N1, dutytab[2]);	

    /* 配置输出管脚 */
    T16Nx_Pins_Init();

    /* 使能T16N0、T16N1 */
    T16Nx_ITConfig(T16N0, T16Nx_IT_MAT1, Enable);
    T16Nx_ITConfig(T16N0, T16Nx_IT_MAT3, Enable);
    NVIC_Init(NVIC_T16N0_IRQn, NVIC_Priority_1, Enable);
	
    T16Nx_ITConfig(T16N1, T16Nx_IT_MAT1, Enable);
    NVIC_Init(NVIC_T16N1_IRQn, NVIC_Priority_1, Enable);


    T16Nx_Enable(T16N0);
    T16Nx_Enable(T16N1);

    return;
}

