/*********************************************************
*Copyright (C), 2017, Shanghai Eastsoft Microelectronics Co., Ltd.
*文件名:  timer.h
*作  者:  AE Team
*版  本:  V1.01
*日  期:  2021/05/19
*描  述:  Timer模块程序头文件
*备  注:  本软件仅供学习和演示使用，对用户直接引用代码所带来的风险或后果不承担任何法律责任。
**********************************************************/
#include "timer.h"


/*********************************************************
函数名: void T32N_Pin_Init(void)
描  述: T32N输入捕捉端口初始化
输入值: 无
输出值: 无
返回值: 无
**********************************************************/
void T32N_Pin_Init(void)
{
    GPIO_InitSettingType x;

    x.Signal = GPIO_Pin_Signal_Digital;
    x.Dir = GPIO_Direction_Input;
    x.Func = GPIO_Reuse_Func2;
    x.PUE = GPIO_PUE_Input_Disable;
    x.PDE = GPIO_PDE_Input_Disable;

    GPIO_Init(GPIO_Pin_A2, &x);
    GPIO_Init(GPIO_Pin_A3, &x);
}

/*********************************************************
函数名: void T32N0Init(void)
描  述: T32N0初始化
输入值: 无
输出值: 无
返回值: 无
**********************************************************/
void T32NxInit(void)
{
    T32Nx_BaseInitStruType x;
    T32Nx_CapInitStruType  y;

    /* 内部时钟，预分频为1:1 */
    x.T32Nx_ClkS   = T32Nx_ClkS_PCLK;
    x.T32Nx_Mode   = T32Nx_Mode_CAP;
    x.T32Nx_PREMAT = 0x01;
    x.T32Nx_SYNC = Disable;             /* 不同步外部时钟 */
    x.T32Nx_EDGE = T32Nx_EDGE_Rise;     /* 外部时钟计数边沿选择:上升沿 */
    T32Nx_BaseInit(T32N0, &x);

    /* 捕捉0/1重载计数器使能，捕捉三次后重载，捕捉输入端口0/1使能，上升沿捕捉 */
    y.T32Nx_CAPCAPL0 = Enable;
    y.T32Nx_CAPCAPL1 = Enable;
    y.T32Nx_CapFall = Disable;
    y.T32Nx_CapRise = Enable;
    y.T32Nx_CapIS0 = Enable;
    y.T32Nx_CapIS1 = Enable;
    y.T32Nx_CapTime = T32Nx_CapTime_3;
    T32Nx_CapInit(T32N0, &y);

    /* MAT0/MAT1/MAT2/MAT3继续计数，不产生中断 */
    T32Nx_MAT0ITConfig(T32N0, T32Nx_Go_No);
    T32Nx_MAT1ITConfig(T32N0, T32Nx_Go_No);
    T32Nx_MAT2ITConfig(T32N0, T32Nx_Go_No);
    T32Nx_MAT3ITConfig(T32N0, T32Nx_Go_No);

    /* 配置CON0以及MAT0、MAT1、MAT2、MAT3 */
    T32Nx_SetCNT(T32N0, 0);
    /* T16N0IN0：MAT0、MAT2 */
    /* T16N0IN0：MAT1、MAT3 */

    /* 中断使能 */
    T32Nx_ITConfig(T32N0, T32Nx_IT_CAP0, Enable);
    T32Nx_ITConfig(T32N0, T32Nx_IT_CAP1, Enable);
    NVIC_Init(NVIC_T32N0_IRQn, NVIC_Priority_1, Enable);

    T32N_Pin_Init();

    T32Nx_Enable(T32N0);

    return;
}
